medmod-package: medmod: Simple Mediation and Moderation Analysis

medmod-packageR Documentation

medmod: Simple Mediation and Moderation Analysis

Description

This toolbox allows you to do simple mediation and moderation analysis. Models are estimated with the 'lavaan' package by Rosseel (2012) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v048.i02")}; standard errors for the mediation estimates are computed with the delta method following Sobel (1982) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2307/270723")} or by bootstrapping. It is also available as a module for 'jamovi' (see https://www.jamovi.org for more information). You can find an in depth tutorial on the 'lavaan' model syntax used for this package on https://lavaan.ugent.be/tutorial/index.html.

Details

Simple mediation analysis med()
Simple moderation analysis mod()

Author(s)

Maintainer: Ravi Selker selker.ravi@gmail.com

Authors:

See Also

Useful links:


medmod documentation built on July 16, 2026, 9:07 a.m.