| med | R Documentation |
Simple mediation analysis. Estimates the indirect, direct and total effects of a model in which a predictor influences the dependent variable through a mediator. The model is fitted with the lavaan package (Rosseel, 2012); standard errors are computed with the delta method (equivalent to the Sobel test for the indirect effect) or by bootstrapping. Optionally provides the individual path estimates, an estimate plot, and an annotated path diagram of the model.
med(
data,
dep,
med,
pred,
estMethod = "standard",
bootstrap = 1000,
test = TRUE,
ci = FALSE,
ciWidth = 95,
pm = FALSE,
paths = FALSE,
label = FALSE,
estPlot = FALSE,
pathDiagram = FALSE,
pathDiagramLabel = TRUE,
pathDiagramEst = TRUE,
pathDiagramSig = TRUE
)
data |
the data as a data frame |
dep |
a string naming the dependent variable |
med |
a string naming the mediator variable |
pred |
a string naming the predictor variable |
estMethod |
|
bootstrap |
a number between 1 and 100000 (default: 1000) specifying the number of samples that need to been drawn in the bootstrap method |
test |
|
ci |
|
ciWidth |
a number between 50 and 99.9 (default: 95) specifying the
confidence interval width that is used as |
pm |
|
paths |
|
label |
|
estPlot |
|
pathDiagram |
|
pathDiagramLabel |
|
pathDiagramEst |
|
pathDiagramSig |
|
A results object containing:
results$med | a table containing mediation estimates | ||||
results$paths | a table containing the individual path estimates | ||||
results$pathDiagram | an image | ||||
results$estPlot | an image | ||||
results$modelSyntax | the lavaan syntax used to fit the mediation model | ||||
Tables can be converted to data frames with asDF or as.data.frame. For example:
results$med$asDF
as.data.frame(results$med)
set.seed(1234)
X <- rnorm(100)
M <- 0.5*X + rnorm(100)
Y <- 0.7*M + rnorm(100)
dat <- data.frame(X=X, M=M, Y=Y)
med(dat, dep = "Y", pred = "X", med = "M")
#
# Mediation Estimates
# -----------------------------------------------------
# Effect Estimate SE Z p
# -----------------------------------------------------
# Indirect 0.3736 0.0920 4.059 < .001
# Direct 0.0364 0.1044 0.348 0.728
# Total 0.4100 0.1247 3.287 0.001
# -----------------------------------------------------
#
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.