| medmod-package | R Documentation |
This toolbox allows you to do simple mediation and moderation analysis. Models are estimated with the 'lavaan' package by Rosseel (2012) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v048.i02")}; standard errors for the mediation estimates are computed with the delta method following Sobel (1982) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2307/270723")} or by bootstrapping. It is also available as a module for 'jamovi' (see https://www.jamovi.org for more information). You can find an in depth tutorial on the 'lavaan' model syntax used for this package on https://lavaan.ugent.be/tutorial/index.html.
| Simple mediation analysis | med() |
| Simple moderation analysis | mod() |
Maintainer: Ravi Selker selker.ravi@gmail.com
Authors:
Ravi Selker selker.ravi@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.