| mod | R Documentation |
Simple moderation analysis. Estimates a model in which the effect of a predictor on the dependent variable depends on the value of a moderator, testing the main effects of predictor and moderator and their interaction. All variables are mean-centered before the model is fitted with the lavaan package (Rosseel, 2012); standard errors are computed with the delta method or by bootstrapping. Optionally provides a simple slope analysis with a corresponding plot, and an annotated path diagram of the model.
mod(
data,
dep,
mod,
pred,
estMethod = "standard",
bootstrap = 1000,
label = FALSE,
test = TRUE,
ci = FALSE,
ciWidth = 95,
pathDiagram = FALSE,
pathDiagramLabel = TRUE,
pathDiagramEst = TRUE,
pathDiagramSig = TRUE,
pathDiagramMainEffect = FALSE,
simpleSlopeEst = FALSE,
simpleSlopePlot = FALSE
)
data |
the data as a data frame |
dep |
a string naming the dependent variable |
mod |
a string naming the moderator variable |
pred |
a string naming the predictor variable |
estMethod |
|
bootstrap |
a number between 1 and 100000 (default: 1000) specifying the number of samples that need to been drawn in the bootstrap method |
label |
|
test |
|
ci |
|
ciWidth |
a number between 50 and 99.9 (default: 95) specifying the
confidence interval width that is used as |
pathDiagram |
|
pathDiagramLabel |
|
pathDiagramEst |
|
pathDiagramSig |
|
pathDiagramMainEffect |
|
simpleSlopeEst |
|
simpleSlopePlot |
|
A results object containing:
results$mod | a table containing moderation estimates | ||||
results$pathDiagram | an image | ||||
results$simpleSlope$estimates | a table containing the simple slope estimates | ||||
results$simpleSlope$plot | an image | ||||
results$modelSyntax | the lavaan syntax used to fit the moderation model | ||||
Tables can be converted to data frames with asDF or as.data.frame. For example:
results$mod$asDF
as.data.frame(results$mod)
set.seed(1234)
X <- rnorm(100)
M <- rnorm(100)
X_M <- X*M
Y <- 0.7*X + 0.1*M + 4.2*X_M + rnorm(100)
dat <- data.frame(X=X, M=M, Y=Y)
mod(dat, dep = "Y", pred = "X", mod = "M")
#
# Moderation Estimates
# --------------------------------------------------
# Estimate SE Z p
# --------------------------------------------------
# X 0.951 0.0965 9.86 < .001
# M -0.471 0.0923 -5.10 < .001
# X:M 4.185 0.1009 41.50 < .001
# --------------------------------------------------
#
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.